@@ -47,10 +47,17 @@ class UniqueKeyQueue:
     def get_batch(self, block=False, timeout=None, num=1000):
         data_list = []
         try:
+            lock.acquire()
             while len(data_list) < num:
-                data_list.append(self._queue.get(block=block, timeout=timeout))
+                data, qid, key = self._queue.get(block=block, timeout=timeout)
+                self._queue_set.remove(key)
+                if not self._ack:
+                    del self._dict[qid]
+                data_list.append(data, qid)
         except Empty:
             pass
+        finally:
+            lock.release()
         return data_list
 
     def ack(self, qid):
