@@ -22,13 +22,16 @@ class SimpleAgentClient:
         return qid_list
 
     def receive_batch(self, max_num):
-        datas = []
-        for i in range(max_num):
-            data, qid = self._register_manager.get(self._topic_name)
-            if data is None:
-                break
-            datas.append((data, qid))
-        return datas
+        return self._register_manager.get_batch(self._topic_name, max_num)
+
+    # def receive_batch(self, max_num):
+    #     datas = []
+    #     for i in range(max_num):
+    #         data, qid = self._register_manager.get(self._topic_name)
+    #         if data is None:
+    #             break
+    #         datas.append((data, qid))
+    #     return datas
 
     # def receive_batch(self, num):
     #     datas = [self._register_manager.get(self._topic_name) for i in range(num)]
